==> openshift-model-operatorhub-5.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubscriptionSpecBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecBuilder>{
  public SubscriptionSpecBuilder() {
    this(false);
  }
  public SubscriptionSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SubscriptionSpec(), validationEnabled);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubscriptionSpec(), validationEnabled);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec instance) {
    this(fluent, instance, false);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withChannel(instance.getChannel()); 
    fluent.withConfig(instance.getConfig()); 
    fluent.withInstallPlanApproval(instance.getInstallPlanApproval()); 
    fluent.withName(instance.getName()); 
    fluent.withSource(instance.getSource()); 
    fluent.withSourceNamespace(instance.getSourceNamespace()); 
    fluent.withStartingCSV(instance.getStartingCSV()); 
    this.validationEnabled = validationEnabled; 
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec instance) {
    this(instance,false);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withChannel(instance.getChannel()); 
    this.withConfig(instance.getConfig()); 
    this.withInstallPlanApproval(instance.getInstallPlanApproval()); 
    this.withName(instance.getName()); 
    this.withSource(instance.getSource()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withStartingCSV(instance.getStartingCSV()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec build() {
    SubscriptionSpec buildable = new SubscriptionSpec(fluent.getChannel(),fluent.getConfig(),fluent.getInstallPlanApproval(),fluent.getName(),fluent.getSource(),fluent.getSourceNamespace(),fluent.getStartingCSV());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionSpecBuilder that = (SubscriptionSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubscriptionSpecBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecBuilder>{
  public SubscriptionSpecBuilder() {
    this(false);
  }
  public SubscriptionSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SubscriptionSpec(), validationEnabled);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubscriptionSpec(), validationEnabled);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec instance) {
    this(fluent, instance, false);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withChannel(instance.getChannel()); 
    fluent.withConfig(instance.getConfig()); 
    fluent.withInstallPlanApproval(instance.getInstallPlanApproval()); 
    fluent.withName(instance.getName()); 
    fluent.withSource(instance.getSource()); 
    fluent.withSourceNamespace(instance.getSourceNamespace()); 
    fluent.withStartingCSV(instance.getStartingCSV()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec instance) {
    this(instance,false);
  }
  public SubscriptionSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withChannel(instance.getChannel()); 
    this.withConfig(instance.getConfig()); 
    this.withInstallPlanApproval(instance.getInstallPlanApproval()); 
    this.withName(instance.getName()); 
    this.withSource(instance.getSource()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withStartingCSV(instance.getStartingCSV()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionSpec build() {
    SubscriptionSpec buildable = new SubscriptionSpec(fluent.getChannel(),fluent.getConfig(),fluent.getInstallPlanApproval(),fluent.getName(),fluent.getSource(),fluent.getSourceNamespace(),fluent.getStartingCSV());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionSpecBuilder that = (SubscriptionSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
